@@ -1,21 +1,24 @@
 from django import forms
 
+WIDGET = forms.PasswordInput
 
-class BaseUserForm(forms.ModelForm):
-    password_1 = forms.CharField(
-        label="Enter a new password", widget=forms.PasswordInput, required=False,
-    )
-    password_2 = forms.CharField(
-        label="Repeat a new password", widget=forms.PasswordInput, required=False,
-    )
+
+class BaseUserOptionalFieldsForm(forms.ModelForm):
+    """
+    Base model form with optional `password_1` and `password_2` fields.
+    This form suitable for edit view in admin panel.
+    """
+
+    password_1 = forms.CharField(label="Enter a new password", widget=WIDGET, required=False,)
+    password_2 = forms.CharField(label="Repeat a new password", widget=WIDGET, required=False,)
 
     class Meta:
         exclude = ["password"]
 
     def clean(self):
         cleaned_data = super().clean()
-        password_1 = cleaned_data["password_1"]
-        password_2 = cleaned_data["password_2"]
+        password_1 = cleaned_data.get("password_1", "")
+        password_2 = cleaned_data.get("password_2", "")
 
         password_list = [password_1, password_2]
         not_empty_password_list = [item for item in password_list if item]
@@ -44,3 +47,16 @@ class BaseUserForm(forms.ModelForm):
         instance.save()
 
         return instance
+
+
+class BaseUserRequiredFieldsForm(BaseUserOptionalFieldsForm):
+    """
+    Base model form with required `password_1` and `password_2` fields.
+    This form suitable for add view in admin panel.
+    """
+
+    password_1 = forms.CharField(label="Enter a new password", widget=WIDGET,)
+    password_2 = forms.CharField(label="Repeat a new password", widget=WIDGET,)
+
+    class Meta:
+        exclude = ["password"]
